@@ -5,6 +5,7 @@
 source ./DefConf.inc
 
 DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc"
+MANFILES="rottlog.8 rottlogex.5"
 
 echo "install script for Rot[t]Log v.$VERSION"
 echo
@@ -50,6 +51,16 @@ for D in $DOCFILES; do
   install -o $LOG_OWN -g $LOG_GROUP -m 0644 $D $DOCDIR/rottlog-$VERSION
 done
 
+for M in $MANFILES; do
+  posnum=${#M}
+  posnum=$[ posnum - 1 ]
+  number=${M:posnum}
+  install -o $LOG_OWN -g $LOG_GROUP -m 0644 $M "$MANDIR/man"$number
+  if [ $MANGZIP -eq 1 ]; then
+    gzip -9 "$MANDIR/man"$number/$M
+  fi
+done
+
 mkdir -p $ROTT_ETCDIR
 chmod $ETC_MODE $ROTT_ETCDIR
 
